library simple_type;

import 'dart:developer' as dev;
import 'dart:math';
import 'dart:ui';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:simple_code/simple_code.dart';
import 'package:intl/intl.dart' as intl;

part 'src/animated_icon.dart';
part 'src/animated_text.dart';
part 'src/animated_widget.dart';
part 'src/extensions/context_extension.dart';
part 'src/extensions/icon_extension.dart';
part 'src/extensions/iterable_extension.dart';
part 'src/extensions/num_extension.dart';
part 'src/extensions/string_extension.dart';
part 'src/extensions/list_extension.dart';
part 'src/extensions/text_extension.dart';
part 'src/extensions/text_span_extension.dart';
part 'src/extensions/widget_extension.dart';
part 'src/utils.dart';

class _SimpleCode {
  bool _wsz = false;
  bool _hsz = false;
  bool _sz = false;

  void useWsz() => _clear(wsz: true);

  void useHsz() => _clear(hsz: true);

  void useSz() => _clear(sz: true);

  void _clear({bool sz, bool hsz, bool wsz}) {
    _sz = sz ?? false;
    _hsz = hsz ?? false;
    _wsz = wsz ?? false;
  }

  double _apply(double value) {
    if (value == null) return value;
    if (_wsz) return wsz(value);
    if (_hsz) return hsz(value);
    if (_sz) return wsz(value);
    return value;
  }
}

class St {
  static _SimpleCode sc = _SimpleCode();

  static double _apply(double value) => sc._apply(value);

  static void log(String log, {String tag}) => dev.log(log, name: tag ?? "log");

  static void error(Object error, {String tag}) =>
      dev.log('', error: error, name: tag ?? "error");

  ///Checks whether debug mode or not
  static bool get isDebugMode => SimpleUtils.isDev;

  /// Get Random Primary Color
  static Color get randomPrimaryColor =>
      Colors.primaries[Random().nextInt(Colors.primaries.length)];

  /// Get Random Non-Primary Color
  static Color get randomColor => Color(Random().nextInt(0xffffffff));

  /// Get Random Non-Primary Color
  static Color get randomOpaqueColor =>
      Color(Random().nextInt(0xffffffff)).withAlpha(0xff);

  static Widget widget({Widget child}) =>
      child ??
      LimitedBox(
        maxWidth: 0.0,
        maxHeight: 0.0,
        child: ConstrainedBox(
          constraints: const BoxConstraints.expand(),
        ),
      );

  static Text text(
    String data, {
    TextStyle style,
    StrutStyle strutStyle,
    TextAlign textAlign,
    TextDirection textDirection,
    Locale locale,
    bool softWrap,
    TextOverflow overflow,
    double textScaleFactor,
    int maxLines,
    String semanticsLabel,
    TextWidthBasis textWidthBasis,
    bool animate = false,
  }) =>
      animate
          ? _StyledAnimatedTextContainer(
              data,
              locale: locale,
              maxLines: maxLines,
              overflow: overflow,
              semanticsLabel: semanticsLabel,
              softWrap: softWrap,
              strutStyle: strutStyle,
              style: style,
              textAlign: textAlign,
              textDirection: textDirection,
              textScaleFactor: textScaleFactor,
              textWidthBasis: textWidthBasis,
            )
          : Text(
              data,
              locale: locale,
              maxLines: maxLines,
              overflow: overflow,
              semanticsLabel: semanticsLabel,
              softWrap: softWrap,
              strutStyle: strutStyle,
              style: style,
              textAlign: textAlign,
              textDirection: textDirection,
              textScaleFactor: textScaleFactor,
              textWidthBasis: textWidthBasis,
            );

  static Icon icon(IconData icon,
          {Key key,
          double size,
          Color color,
          String semanticLabel,
          TextDirection textDirection,
          bool animate = false}) =>
      animate
          ? _StyledAnimatedIconContainer(
              icon,
              color: color,
              size: size,
              semanticLabel: semanticLabel,
              textDirection: textDirection,
            )
          : Icon(
              icon,
              color: color,
              size: St._apply(size),
              semanticLabel: semanticLabel,
              textDirection: textDirection,
            );
}
