part of '../../simple_type.dart';

extension StyledList<E> on List<Widget> {
  Column toColumn({
    Key key,
    MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start,
    MainAxisSize mainAxisSize = MainAxisSize.max,
    CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center,
    TextDirection textDirection,
    VerticalDirection verticalDirection = VerticalDirection.down,
    TextBaseline textBaseline,
  }) =>
      Column(
        key: key,
        mainAxisAlignment: mainAxisAlignment,
        mainAxisSize: mainAxisSize,
        crossAxisAlignment: crossAxisAlignment,
        textDirection: textDirection,
        verticalDirection: verticalDirection,
        textBaseline: textBaseline,
        children: this,
      );

  Row toRow({
    Key key,
    MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start,
    MainAxisSize mainAxisSize = MainAxisSize.max,
    CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center,
    TextDirection textDirection,
    VerticalDirection verticalDirection = VerticalDirection.down,
    TextBaseline textBaseline,
  }) =>
      Row(
        key: key,
        mainAxisAlignment: mainAxisAlignment,
        mainAxisSize: mainAxisSize,
        crossAxisAlignment: crossAxisAlignment,
        textDirection: textDirection,
        verticalDirection: verticalDirection,
        textBaseline: textBaseline,
        children: this,
      );

  Stack toStack({
    Key key,
    AlignmentGeometry alignment = AlignmentDirectional.topStart,
    TextDirection textDirection,
    StackFit fit = StackFit.loose,
    Clip clipBehavior = Clip.hardEdge,
    Overflow overflow = Overflow.clip,
    List<Widget> children = const <Widget>[],
  }) =>
      Stack(
        key: key,
        alignment: alignment,
        textDirection: textDirection,
        fit: fit,
        clipBehavior: clipBehavior,
        overflow: overflow,
        children: this,
      );

  Wrap toWrap({
    Key key,
    WrapAlignment alignment = WrapAlignment.start,
    WrapAlignment runAlignment = WrapAlignment.start,
    WrapCrossAlignment crossAxisAlignment = WrapCrossAlignment.start,
    VerticalDirection verticalDirection = VerticalDirection.down,
    Axis direction = Axis.horizontal,
    double runSpacing = 0.0,
    double spacing = 0.0,
    TextDirection textDirection,
    TextBaseline textBaseline,
    Clip clipBehavior = Clip.hardEdge,
  }) =>
      Wrap(
        key: key,
        crossAxisAlignment: crossAxisAlignment,
        alignment: alignment,
        direction: direction,
        runSpacing: St._apply(runSpacing),
        spacing: St._apply(spacing),
        textDirection: textDirection,
        clipBehavior: clipBehavior,
        runAlignment: runAlignment,
        verticalDirection: verticalDirection,
        children: this,
      );
}

extension ColumnExt on Column {
  Column copyWhith({
    MainAxisAlignment mainAxisAlignment,
    CrossAxisAlignment crossAxisAlignment,
    VerticalDirection verticalDirection,
    MainAxisSize mainAxisSize,
  }) {
    return Column(
      key: this.key,
      mainAxisAlignment: mainAxisAlignment ?? this.mainAxisAlignment,
      mainAxisSize: mainAxisSize ?? this.mainAxisSize,
      crossAxisAlignment: crossAxisAlignment ?? this.crossAxisAlignment,
      verticalDirection: verticalDirection ?? this.verticalDirection,
      textDirection: this.textDirection,
      textBaseline: this.textBaseline,
      children: this.children,
    );
  }

  Column get mainCenter =>
      copyWhith(mainAxisAlignment: MainAxisAlignment.center);

  Column get verticalDown =>
      copyWhith(verticalDirection: VerticalDirection.down);

  Column get verticalUp => copyWhith(verticalDirection: VerticalDirection.up);

  Column get sizeMax => copyWhith(mainAxisSize: MainAxisSize.max);
  Column get sizeMin => copyWhith(mainAxisSize: MainAxisSize.min);

  Column get mainEnd => copyWhith(mainAxisAlignment: MainAxisAlignment.end);

  Column get mainSpaceAround =>
      copyWhith(mainAxisAlignment: MainAxisAlignment.spaceAround);

  Column get mainSpaceBetween =>
      copyWhith(mainAxisAlignment: MainAxisAlignment.spaceBetween);

  Column get mainSpaceEvenly =>
      copyWhith(mainAxisAlignment: MainAxisAlignment.spaceEvenly);

  Column get mainStart => copyWhith(mainAxisAlignment: MainAxisAlignment.start);

  Column get crossStart =>
      copyWhith(crossAxisAlignment: CrossAxisAlignment.start);

  Column get crossBaseline =>
      copyWhith(crossAxisAlignment: CrossAxisAlignment.baseline);

  Column get crossCenter =>
      copyWhith(crossAxisAlignment: CrossAxisAlignment.center);

  Column get crossEnd => copyWhith(crossAxisAlignment: CrossAxisAlignment.end);

  Column get crossStretch =>
      copyWhith(crossAxisAlignment: CrossAxisAlignment.stretch);
}

extension RowExt on Row {
  Row copyWhith({
    MainAxisAlignment mainAxisAlignment,
    CrossAxisAlignment crossAxisAlignment,
    VerticalDirection verticalDirection,
    MainAxisSize mainAxisSize,
  }) {
    return Row(
      key: this.key,
      mainAxisAlignment: mainAxisAlignment ?? this.mainAxisAlignment,
      mainAxisSize: mainAxisSize ?? this.mainAxisSize,
      crossAxisAlignment: crossAxisAlignment ?? this.crossAxisAlignment,
      verticalDirection: verticalDirection ?? this.verticalDirection,
      textDirection: this.textDirection,
      textBaseline: this.textBaseline,
      children: this.children,
    );
  }

  Row get mainCenter => copyWhith(mainAxisAlignment: MainAxisAlignment.center);

  Row get verticalDown => copyWhith(verticalDirection: VerticalDirection.down);

  Row get verticalUp => copyWhith(verticalDirection: VerticalDirection.up);

  Row get sizeMax => copyWhith(mainAxisSize: MainAxisSize.max);
  Row get sizeMin => copyWhith(mainAxisSize: MainAxisSize.min);

  Row get mainEnd => copyWhith(mainAxisAlignment: MainAxisAlignment.end);

  Row get mainSpaceAround =>
      copyWhith(mainAxisAlignment: MainAxisAlignment.spaceAround);

  Row get mainSpaceBetween =>
      copyWhith(mainAxisAlignment: MainAxisAlignment.spaceBetween);

  Row get mainSpaceEvenly =>
      copyWhith(mainAxisAlignment: MainAxisAlignment.spaceEvenly);

  Row get mainStart => copyWhith(mainAxisAlignment: MainAxisAlignment.start);

  Row get crossStart => copyWhith(crossAxisAlignment: CrossAxisAlignment.start);

  Row get crossBaseline =>
      copyWhith(crossAxisAlignment: CrossAxisAlignment.baseline);

  Row get crossCenter =>
      copyWhith(crossAxisAlignment: CrossAxisAlignment.center);

  Row get crossEnd => copyWhith(crossAxisAlignment: CrossAxisAlignment.end);

  Row get crossStretch =>
      copyWhith(crossAxisAlignment: CrossAxisAlignment.stretch);
}
